@@ -26,6 +26,8 @@ SOURCE_ORGANISER_MAPPING: Dict[str, List[str]] = {
     'swift-second-saturdays': ['-sss-'],
 }
 
+TOURNAMENT_ID_REGEX = re.compile("-+([0-9a-fA-F]+)$", re.I)
+
 
 class SimpleSource:
     id: str
@@ -33,13 +35,17 @@ class SimpleSource:
     date: str
     organiser: Optional[str]
     tournament_name: Optional[str]
-    url: Optional[str]
+    tournament_id: Optional[str]
 
     def __init__(self, id: str, name: str):
         """Constructor for SimpleSource"""
         self.id = id
         self.name = name
-        (self.date, self.organiser, self.tournament_name, self.url) = self.initialise(name)
+        (self.date, self.organiser, self.tournament_name, self.tournament_id) = self.initialise(name)
+
+    @property
+    def url(self):
+        return f"https://battlefy.com/_/_/{self.tournament_id}/info" if self.tournament_id else None
 
     @staticmethod
     def from_dict(obj: dict) -> 'SimpleSource':
@@ -60,32 +66,34 @@ class SimpleSource:
         if not source_name:
             return None, None, None, None
 
-        if len(source_name) > 11 and source_name.count('-') > 3:
+        if len(source_name) > 11 and source_name.count('-') > 2:
             date = source_name[0:10].strip('- ')
             default_tourney_name = source_name[11:].strip('- ')
         else:
             date = None
-            default_tourney_name = None
+            default_tourney_name = source_name
 
-        id_at_the_end_match = re.search("-+([0-9a-fA-F]+)$", source_name, re.I)
+        id_at_the_end_match = TOURNAMENT_ID_REGEX.search(source_name)
         if id_at_the_end_match:
             # We always want to grab the last match as the id is at the end of the source name.
-            guid = id_at_the_end_match.groups()[-1]
-            url = f"https://battlefy.com/_/_/{guid}/info"
+            tournament_id = id_at_the_end_match.groups()[-1]
+            default_tourney_name = TOURNAMENT_ID_REGEX.sub('', default_tourney_name, count=1)
         else:
-            url = None
+            tournament_id = None
 
         for organiser, tourneys in SOURCE_ORGANISER_MAPPING.items():
             for tournament_name in tourneys:
                 if tournament_name in source_name:
-                    return date, organiser.strip('- '), tournament_name.strip('- '), url
+                    return date, organiser.strip('- '), tournament_name.strip('- '), tournament_id
         else:
+            # Try and get the organiser from the ORG_SLUGS list.
+            tournament_name = default_tourney_name
             for organiser in battlefy_toolkit.org_lists.splatoon_orgs.ORG_SLUGS:
                 if f"-{organiser}-" in source_name:
-                    tournament_name = SimpleSource._strip_source_id(default_tourney_name.replace(f"-{organiser}-", ''))
-                    return date, organiser.strip('- '), tournament_name.strip('- '), url
+                    tournament_name = tournament_name.replace(f"-{organiser}-", '').strip('- ')
+                    return date, organiser.strip('- '), tournament_name, tournament_id
 
-        return date, None, default_tourney_name, url
+            return date, None, tournament_name, tournament_id
 
     def get_linked_date_display(self) -> str:
         """Return a markdown link with the truncated source date if available,
@@ -115,4 +123,4 @@ class SimpleSource:
 
     @staticmethod
     def _strip_source_id(source):
-        return re.sub("-+[0-9a-fA-F]+$", '', source)
+        return TOURNAMENT_ID_REGEX.sub('', source)
