@@ -1,7 +1,6 @@
 import asyncio
 import glob
 import json
-import re
 from datetime import datetime
 from os.path import join, relpath
 from typing import Set, Optional, Collection, Tuple, Dict, Union, Iterable, List, Any
@@ -17,12 +16,13 @@ from slapp_py.core_classes.player import Player
 from slapp_py.core_classes.score import Score
 from slapp_py.core_classes.source import Source
 from slapp_py.core_classes.team import Team
+from slapp_py.helpers.battlefy_helper import is_valid_battlefy_id, filter_non_battlefy_source
 from slapp_py.helpers.dict_helper import first_key, add_set_by_key
 from slapp_py.helpers.str_helper import is_none_or_whitespace
 from slapp_py.misc.download_from_battlefy_result import get_or_fetch_tourney_teams_file, get_stage_ids_for_tourney, \
     get_or_fetch_stage_file, get_or_fetch_standings_file
 from slapp_py.misc.slapp_files_utils import TOURNEY_TEAMS_SAVE_DIR, get_latest_sources_yaml_file, \
-    load_latest_snapshot_sources_file, load_latest_snapshot_players_file
+    load_latest_snapshot_sources_file, load_latest_snapshot_players_file, get_slapp_files_matching
 from slapp_py.slapp_runner.slapipes import SLAPP_DATA_FOLDER, SlapPipe
 
 
@@ -62,10 +62,11 @@ def fetch_tournament_ids(save_path: Optional[str] = None) -> Set[str]:
     return full_tourney_ids
 
 
-def generate_new_sources_files(battlefy_ids: Collection) -> Tuple[str, str]:
+def generate_new_sources_files(battlefy_ids: Collection[str], skip_redownload: bool = False) -> Tuple[str, str]:
     """
     Take the collection of (new) battlefy ids and generate a new sources file and a patch file.
     :param battlefy_ids: Collection of (new) battlefy ids to process.
+    :param skip_redownload: Skip the redownload of files if a failure has occurred?
     :returns: A tuple containing the file path to the new sources file, and new patch file.
     """
 
@@ -93,37 +94,52 @@ def generate_new_sources_files(battlefy_ids: Collection) -> Tuple[str, str]:
             if len(matched_tourney_teams_files) == 1:
                 relative_path = relpath(matched_tourney_teams_files[0], start=SLAPP_DATA_FOLDER)
                 if not relative_path.startswith('.'):
-                    relative_path = '.\\' + relative_path
+                    relative_path = './' + relative_path
                 processed_tourney_ids[tourney_id] = (relative_path, True)
             else:
                 print(f"ERROR: Found an updated tourney file but a unique file wasn't downloaded for it: "
                       f"{tourney_id=}, {len(matched_tourney_teams_files)=}")
-                print("Re-attempting download...")
-                if get_or_fetch_tourney_teams_file(tourney_id):
-                    print("Success!")
-                    matched_tourney_teams_files = glob.glob(join(TOURNEY_TEAMS_SAVE_DIR, f'*{filename}'))
-                    if len(matched_tourney_teams_files) == 1:
-                        relative_path = relpath(matched_tourney_teams_files[0], start=SLAPP_DATA_FOLDER)
-                        processed_tourney_ids[tourney_id] = (relative_path, True)
-                    else:
-                        print(f"ERROR: Reattempt failed. Please debug."
-                              f"{tourney_id=}, {len(matched_tourney_teams_files)=}")
+                if skip_redownload:
+                    continue
                 else:
-                    print(f"ERROR: Reattempt failed. Skipping file."
-                          f"{tourney_id=}, {len(matched_tourney_teams_files)=}")
+                    print("Re-attempting download...")
+                    if get_or_fetch_tourney_teams_file(tourney_id):
+                        print("Success!")
+                        matched_tourney_teams_files = glob.glob(join(TOURNEY_TEAMS_SAVE_DIR, f'*{filename}'))
+                        if len(matched_tourney_teams_files) == 1:
+                            relative_path = relpath(matched_tourney_teams_files[0], start=SLAPP_DATA_FOLDER)
+                            processed_tourney_ids[tourney_id] = (relative_path, True)
+                        else:
+                            print(f"ERROR: Reattempt failed. Please debug. "
+                                  f"{tourney_id=}, {len(matched_tourney_teams_files)=}")
+                    else:
+                        print(f"ERROR: Reattempt failed. Skipping file. "
+                              f"{tourney_id=}, {len(matched_tourney_teams_files)=}")
+
+    # And the other data files
+    additional_files = []
+    additional_files.extend(get_slapp_files_matching('*-Sendou.json', TOURNEY_TEAMS_SAVE_DIR))
+    additional_files.extend(get_slapp_files_matching('*-LUTI-S*.tsv', TOURNEY_TEAMS_SAVE_DIR))
+    additional_files.extend(get_slapp_files_matching('*-DSB-S*.tsv', TOURNEY_TEAMS_SAVE_DIR))
+
+    for additional_file in additional_files or []:
+        relative_path = relpath(additional_file, start=SLAPP_DATA_FOLDER)
+        if not relative_path.startswith('.'):
+            relative_path = './' + relative_path
+        relative_path = relative_path.replace('\\', '/')
+        found_line = next((line for line in sources_contents if line.replace('\\', '/').endswith(relative_path)), None)
+        is_new = not found_line
+        if found_line:
+            # Not new
+            processed_tourney_ids[additional_file] = (found_line, False)
+        else:
+            processed_tourney_ids[additional_file] = (relative_path, True)
+        print(f"{additional_file=}, {SLAPP_DATA_FOLDER=}, {relative_path=}, {is_new=}")
 
     # Now update the yaml
     print(f"Updating the yaml ({len(sources_contents)} sources).")
+
     # Take care of those pesky exceptions to the rule
-
-    # Sendou goes first (but only if not dated)
-    # If dated, it's special and should be added back in
-    if 'Sendou.json' in sources_contents[0]:
-        sendou_str = sources_contents[0]
-        sources_contents.remove(sources_contents[0])
-    else:
-        sendou_str = None
-
     # statink folder is special
     if './statink' in sources_contents:
         statink_present = True
@@ -163,10 +179,6 @@ def generate_new_sources_files(battlefy_ids: Collection) -> Tuple[str, str]:
     if statink_present:
         sources_contents.insert(0, './statink')
 
-    # To the start
-    if sendou_str:
-        sources_contents.insert(0, sendou_str)
-
     # To the end
     if twitter_str:
         sources_contents.append(twitter_str)
@@ -272,20 +284,6 @@ def team_persistent_id_to_slapp_id(_persistent_team_id: Union[str, UUID], _teams
         return None
 
 
-def is_valid_battlefy_id(_battlefy_id: str) -> bool:
-    """
-    Filter out ids that are less than 20 characters or more than 30 (id is probably not correct) and not hex.
-    Expected 24 chars, and hex numbers only.
-    :param _battlefy_id: The id to test
-    :return: True if valid else False.
-    """
-    return 20 <= len(_battlefy_id) < 30 and re.match("^[A-Fa-f0-9]*$", _battlefy_id)
-
-
-def filter_non_battlefy_source(source_name: str):
-    return not any(x in source_name for x in ["-stat.ink-", "-LUTI-", "Twitter-"])
-
-
 def get_source_by_tourney_id(tourney_id: str,
                              sources: List[Source]) -> Optional[Source]:
     return next((s for s in sources if s.tournament_id == tourney_id), None)
@@ -306,7 +304,7 @@ def add_tourney_placement_to_source(tourney_id: str,
         print(f"Could not find a source in the snapshot that matches {tourney_id=}. Not adding.")
         return False
 
-    if source.brackets:
+    if source.brackets and source.brackets[0].is_valid and source.brackets[-1].is_valid:
         print(f"Brackets already exist for this source. Skipping.")
         return False
 
@@ -372,7 +370,7 @@ def add_tourney_placement_to_source(tourney_id: str,
                 }
                 game = Game(score=Score([team_result_1.get("score", -1), team_result_2.get("score", -1)]),
                             ids=ids_dictionary)
-                bracket.matches.add(game)
+                bracket.matches.append(game)
             else:
                 print(f"Skipping game in {json.dumps(match)} - the team(s) were not matched to Slapp ids.")
 
